function xnext = f_car(x, u, w, delta_t)

% very simple euler integration model for Dubin's model for a car
% this model assumes 
%        rear wheels move straight ahead
%        front wheels move in direction they face, too
%    no slippage

% x = [x; y; theta; v; s]

% x: x coordinate
% y: y coordinate
% theta: heading
% v: velocity
% s: steering angle

% u = [vstar; sstar]
% 
% vstar = commanded target velocity
% sstar = commanded target steering angle
%


x_idx = 1;
y_idx = 2;
theta_idx = 3;
v_idx = 4;
s_idx = 5;

vstar_idx = 1;
sstar_idx = 2;

xnext = zeros(5,1);

xnext(x_idx) = x(x_idx) + x(v_idx)*cos(x(theta_idx));
xnext(y_idx) = x(y_idx) + x(v_idx)*sin(x(theta_idx));

wheelbase = 1.5; % distance between front and rear axis

omega = x(v_idx) / wheelbase * tan(x(s_idx)); 

xnext(theta_idx) = x(theta_idx) + delta_t * omega;

xnext(v_idx) = x(v_idx) + (u(vstar_idx) - x(v_idx))*0.7;

xnext(s_idx) = x(s_idx) + (u(sstar_idx) - x(s_idx))*0.7;

xnext = xnext + w;
